==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/TrendMicroApexOneServiceApplicationSettingsApplication.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Trend Micro Apex One as a Service app instance properties
 */
@ApiModel(description = "Trend Micro Apex One as a Service app instance properties")
@JsonPropertyOrder({ TrendMicroApexOneServiceApplicationSettingsApplication.JSON_PROPERTY_BASE_U_R_L })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class TrendMicroApexOneServiceApplicationSettingsApplication implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_BASE_U_R_L = "baseURL";
    private String baseURL;

    public TrendMicroApexOneServiceApplicationSettingsApplication() {
    }

    public TrendMicroApexOneServiceApplicationSettingsApplication baseURL(String baseURL) {

        this.baseURL = baseURL;
        return this;
    }

    /**
     * Base Trend Micro Apex One Service URL
     *
     * @return baseURL
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(required = true, value = "Base Trend Micro Apex One Service URL")
    @JsonProperty(JSON_PROPERTY_BASE_U_R_L)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public String getBaseURL() {
        return baseURL;
    }

    @JsonProperty(JSON_PROPERTY_BASE_U_R_L)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setBaseURL(String baseURL) {
        this.baseURL = baseURL;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        TrendMicroApexOneServiceApplicationSettingsApplication trendMicroApexOneServiceApplicationSettingsApplication = (TrendMicroApexOneServiceApplicationSettingsApplication) o;
        return Objects.equals(this.baseURL, trendMicroApexOneServiceApplicationSettingsApplication.baseURL);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(baseURL);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class TrendMicroApexOneServiceApplicationSettingsApplication {\n");
        sb.append("    baseURL: ").append(toIndentedString(baseURL)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: com/okta/sdk/resource/model/TrendMicroApexOneServiceApplicationSettingsApplication.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Trend Micro Apex One as a Service app instance properties
 */
@ApiModel(description = "Trend Micro Apex One as a Service app instance properties")
@JsonPropertyOrder({ TrendMicroApexOneServiceApplicationSettingsApplication.JSON_PROPERTY_BASE_U_R_L })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class TrendMicroApexOneServiceApplicationSettingsApplication implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_BASE_U_R_L = "baseURL";
    private String baseURL;

    public TrendMicroApexOneServiceApplicationSettingsApplication() {
    }

    public TrendMicroApexOneServiceApplicationSettingsApplication baseURL(String baseURL) {

        this.baseURL = baseURL;
        return this;
    }

    /**
     * Base Trend Micro Apex One Service URL
     *
     * @return baseURL
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(required = true, value = "Base Trend Micro Apex One Service URL")
    @JsonProperty(JSON_PROPERTY_BASE_U_R_L)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public String getBaseURL() {
        return baseURL;
    }

    @JsonProperty(JSON_PROPERTY_BASE_U_R_L)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setBaseURL(String baseURL) {
        this.baseURL = baseURL;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        TrendMicroApexOneServiceApplicationSettingsApplication trendMicroApexOneServiceApplicationSettingsApplication = (TrendMicroApexOneServiceApplicationSettingsApplication) o;
        return Objects.equals(this.baseURL, trendMicroApexOneServiceApplicationSettingsApplication.baseURL);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(baseURL);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class TrendMicroApexOneServiceApplicationSettingsApplication {\n");
        sb.append("    baseURL: ").append(toIndentedString(baseURL)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
